pub struct DigitComponents;Expand description
Digits-related circuit components
Implementations
Sourceimpl DigitComponents
impl DigitComponents
Sourcepub fn unsigned_recomposition<F: Field>(
builder_ref: &mut CircuitBuilder<F>,
mles: &[&NodeRef<F>],
base: u64,
) -> NodeRef<F>
pub fn unsigned_recomposition<F: Field>( builder_ref: &mut CircuitBuilder<F>, mles: &[&NodeRef<F>], base: u64, ) -> NodeRef<F>
Digital recomposition of an unsigned integer, i.e. deriving the number from its digits.
Each of the Nodes in mles specifies the digits for a different
“decimal place”. Most significant digit comes first.
Sourcepub fn complementary_recomp_check<F: Field>(
builder_ref: &mut CircuitBuilder<F>,
values: &NodeRef<F>,
bits: &NodeRef<F>,
unsigned_recomps: &NodeRef<F>,
base: u64,
num_digits: usize,
) -> NodeRef<F>
pub fn complementary_recomp_check<F: Field>( builder_ref: &mut CircuitBuilder<F>, values: &NodeRef<F>, bits: &NodeRef<F>, unsigned_recomps: &NodeRef<F>, base: u64, num_digits: usize, ) -> NodeRef<F>
Checks that the complementary decomposition of a signed
integer. To be used in conjunction with Self::unsigned_recomposition. See
crate::digits::complementary_decomposition and
Notion.
Add self.sector to the circuit as an output layer to enforce this constraint.
Create a new ComplementaryDecompChecker. values are the original
values. bits are the bits of the complementary decomposition.
unsigned_recomps are the unsigned recompositions.
Sourcepub fn bits_are_binary<F: Field>(
builder_ref: &mut CircuitBuilder<F>,
values_node: &NodeRef<F>,
) -> NodeRef<F>
pub fn bits_are_binary<F: Field>( builder_ref: &mut CircuitBuilder<F>, values_node: &NodeRef<F>, ) -> NodeRef<F>
Ensures that each bit is either 0 or 1. Add self.sector to the circuit as an output layer to enforce this constraint.
Sourcepub fn digits_concatenator<F: Field>(
builder_ref: &mut CircuitBuilder<F>,
mles: &[&NodeRef<F>],
) -> NodeRef<F>
pub fn digits_concatenator<F: Field>( builder_ref: &mut CircuitBuilder<F>, mles: &[&NodeRef<F>], ) -> NodeRef<F>
A component that concatenates all the separate digit MLEs (there is one for each digital place) into a single MLE using a selector tree. (Necessary to interact with logup).